@@ -28,7 +28,7 @@ public:
     explicit FractionPainter(QWidget * parent = nullptr);
 
     /** destructor */
-    ~FractionPainter();
+    ~FractionPainter() override;
 
     void paintFraction(const QString & str_operation, Ratio & leftRatio, int leftMult,
                        Ratio & rightRatio, int rightMult);
@@ -36,7 +36,7 @@ public:
 protected:
     /** Function is called every time the screen need to be painted.
      **/
-    void paintEvent(QPaintEvent * event) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent * event) override;
     void paintWidget(QPainter & paint);
 
 private:
